@@ -12,7 +12,7 @@ use Data::Object::Library qw(Str);
 
 extends 'API::Client';
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 our $DEFAULT_URL = "https://api.trello.com";
 
@@ -95,7 +95,7 @@ API::Trello - Trello.com API Client
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -169,7 +169,7 @@ The debug attribute if true prints HTTP requests and responses to standard out.
     $trello->fatal(1);
 
 The fatal attribute if true promotes 4xx and 5xx server response codes to
-exceptions, a L<API::Trello::Exception> object.
+exceptions, a L<API::Client::Exception> object.
 
 =head2 retries
 
